// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "confirmaddressplugin_debug.h"


Q_LOGGING_CATEGORY(KMAIL_EDITOR_CONFIRMADDRESS_PLUGIN_LOG, "org.kde.pim.kmail_confirmaddressplugin", QtInfoMsg)

