// This file is generated by kconfig_compiler_kf6 from checkfoldersizeaccount.kcfg.
// All changes you do to this file will be lost.
#ifndef CHECKFOLDERSIZEACCOUNTSETTINGS_H
#define CHECKFOLDERSIZEACCOUNTSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class CheckFolderSizeAccountSettings : public KConfigSkeleton
{
  public:

    static CheckFolderSizeAccountSettings *self();
    ~CheckFolderSizeAccountSettings() override;

    /**
      Set WarningSize
    */
    static
    void setWarningSize( qint64 v )
    {
      if (!self()->isWarningSizeImmutable())
        self()->mWarningSize = v;
    }

    /**
      Get WarningSize
    */
    static
    qint64 warningSize()
    {
      return self()->mWarningSize;
    }

    /**
      Is WarningSize Immutable
    */
    static
    bool isWarningSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WarningSize" ) );
    }

    /**
      Get Item object corresponding to WarningSize()
    */
    ItemLongLong *warningSizeItem()
    {
      return mWarningSizeItem;
    }

  protected:
    CheckFolderSizeAccountSettings();
    friend class CheckFolderSizeAccountSettingsHelper;


    // Global
    qint64 mWarningSize;

  private:
    ItemLongLong *mWarningSizeItem;
};

#endif

