/****************************************************************************
** Meta object code from reading C++ file 'todoedit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdepim-addons-26.07.90/plugins/messageviewerplugins/createtodoplugin/todoedit.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'todoedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13MessageViewer8TodoEditE_t {};
} // unnamed namespace

template <> constexpr inline auto MessageViewer::TodoEdit::qt_create_metaobjectdata<qt_meta_tag_ZN13MessageViewer8TodoEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MessageViewer::TodoEdit",
        "createTodo",
        "",
        "KCalendarCore::Todo::Ptr",
        "todo",
        "Akonadi::Collection",
        "collection",
        "collectionChanged",
        "col",
        "messageChanged",
        "std::shared_ptr<KMime::Message>",
        "msg",
        "slotCloseWidget"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'createTodo'
        QtMocHelpers::SignalData<void(const KCalendarCore::Todo::Ptr &, const Akonadi::Collection &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'collectionChanged'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 },
        }}),
        // Signal 'messageChanged'
        QtMocHelpers::SignalData<void(const std::shared_ptr<KMime::Message> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotCloseWidget'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TodoEdit, qt_meta_tag_ZN13MessageViewer8TodoEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MessageViewer::TodoEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MessageViewer8TodoEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MessageViewer8TodoEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MessageViewer8TodoEditE_t>.metaTypes,
    nullptr
} };

void MessageViewer::TodoEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TodoEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createTodo((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Todo::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 1: _t->collectionChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 2: _t->messageChanged((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<KMime::Message>>>(_a[1]))); break;
        case 3: _t->slotCloseWidget(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KCalendarCore::Todo::Ptr >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< std::shared_ptr<KMime::Message> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TodoEdit::*)(const KCalendarCore::Todo::Ptr & , const Akonadi::Collection & )>(_a, &TodoEdit::createTodo, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoEdit::*)(const Akonadi::Collection & )>(_a, &TodoEdit::collectionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoEdit::*)(const std::shared_ptr<KMime::Message> & )>(_a, &TodoEdit::messageChanged, 2))
            return;
    }
}

const QMetaObject *MessageViewer::TodoEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MessageViewer::TodoEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MessageViewer8TodoEditE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MessageViewer::TodoEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void MessageViewer::TodoEdit::createTodo(const KCalendarCore::Todo::Ptr & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void MessageViewer::TodoEdit::collectionChanged(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MessageViewer::TodoEdit::messageChanged(const std::shared_ptr<KMime::Message> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
