// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "sendmailplugin_debug.h"


Q_LOGGING_CATEGORY(MAILTRANSPORT_PLUGIN_LOG, "org.kde.pim.mailtransport_sendmail", QtInfoMsg)

