// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "libopenurlwithconfigure_debug.h"


Q_LOGGING_CATEGORY(LIBOPENURLWITHCONFIGURE_PLUGIN_LOG, "org.kde.pim.libopenurlwithconfigureplugin", QtInfoMsg)

