// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_KADDRESSBOOK_SENDVCARDS_LOG_KADDRESSBOOK_SENDVCARDSPLUGIN_DEBUG_H
#define ECM_QLOGGINGCATEGORY_KADDRESSBOOK_SENDVCARDS_LOG_KADDRESSBOOK_SENDVCARDSPLUGIN_DEBUG_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(KADDRESSBOOK_SENDVCARDS_LOG)


#endif
