// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_KMAIL_EDITOR_AUTOMATICADDCONTACTS_PLUGIN_LOG_AUTOMATICADDCONTACTSPLUGIN_DEBUG_H
#define ECM_QLOGGINGCATEGORY_KMAIL_EDITOR_AUTOMATICADDCONTACTS_PLUGIN_LOG_AUTOMATICADDCONTACTSPLUGIN_DEBUG_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(KMAIL_EDITOR_AUTOMATICADDCONTACTS_PLUGIN_LOG)


#endif
