/********************************************************************************
** Form generated from reading UI file 'attendeeselector.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ATTENDEESELECTOR_H
#define UI_ATTENDEESELECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "PimCommonAkonadi/AddresseeLineEdit"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_AttendeeSelectorWidget
{
public:
    QGridLayout *gridLayout;
    PimCommon::AddresseeLineEdit *attendeeEdit;
    QPushButton *addButton;
    QListWidget *attendeeList;
    QPushButton *removeButton;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *AttendeeSelectorWidget)
    {
        if (AttendeeSelectorWidget->objectName().isEmpty())
            AttendeeSelectorWidget->setObjectName("AttendeeSelectorWidget");
        AttendeeSelectorWidget->resize(354, 238);
        gridLayout = new QGridLayout(AttendeeSelectorWidget);
        gridLayout->setObjectName("gridLayout");
        attendeeEdit = new PimCommon::AddresseeLineEdit(AttendeeSelectorWidget);
        attendeeEdit->setObjectName("attendeeEdit");

        gridLayout->addWidget(attendeeEdit, 0, 0, 1, 1);

        addButton = new QPushButton(AttendeeSelectorWidget);
        addButton->setObjectName("addButton");
        addButton->setEnabled(false);

        gridLayout->addWidget(addButton, 0, 1, 1, 1);

        attendeeList = new QListWidget(AttendeeSelectorWidget);
        attendeeList->setObjectName("attendeeList");

        gridLayout->addWidget(attendeeList, 1, 0, 2, 1);

        removeButton = new QPushButton(AttendeeSelectorWidget);
        removeButton->setObjectName("removeButton");
        removeButton->setEnabled(false);

        gridLayout->addWidget(removeButton, 1, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 140, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 2, 1, 1, 1);


        retranslateUi(AttendeeSelectorWidget);

        QMetaObject::connectSlotsByName(AttendeeSelectorWidget);
    } // setupUi

    void retranslateUi(QWidget *AttendeeSelectorWidget)
    {
        addButton->setText(tr2i18n("Add", nullptr));
        removeButton->setText(tr2i18n("Remove", nullptr));
        (void)AttendeeSelectorWidget;
    } // retranslateUi

};

namespace Ui {
    class AttendeeSelectorWidget: public Ui_AttendeeSelectorWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ATTENDEESELECTOR_H

