// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "expertplugin_debug.h"


Q_LOGGING_CATEGORY(KMAIL_EXPERT_PLUGIN_LOG, "org.kde.pim.kmail_expertplugin", QtInfoMsg)

