/****************************************************************************
** Meta object code from reading C++ file 'antispamwizard.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kdepim-addons-26.07.90/kmail/plugins/common/antispamwizard.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'antispamwizard.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5KMail14AntiSpamWizardE_t {};
} // unnamed namespace

template <> constexpr inline auto KMail::AntiSpamWizard::qt_create_metaobjectdata<qt_meta_tag_ZN5KMail14AntiSpamWizardE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMail::AntiSpamWizard",
        "checkProgramsSelections",
        "",
        "checkVirusRulesSelections",
        "checkToolAvailability",
        "slotHelpClicked",
        "slotBuildSummary"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'checkProgramsSelections'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'checkVirusRulesSelections'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'checkToolAvailability'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotHelpClicked'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotBuildSummary'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AntiSpamWizard, qt_meta_tag_ZN5KMail14AntiSpamWizardE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMail::AntiSpamWizard::staticMetaObject = { {
    QMetaObject::SuperData::link<KAssistantDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail14AntiSpamWizardE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail14AntiSpamWizardE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5KMail14AntiSpamWizardE_t>.metaTypes,
    nullptr
} };

void KMail::AntiSpamWizard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AntiSpamWizard *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkProgramsSelections(); break;
        case 1: _t->checkVirusRulesSelections(); break;
        case 2: _t->checkToolAvailability(); break;
        case 3: _t->slotHelpClicked(); break;
        case 4: _t->slotBuildSummary(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *KMail::AntiSpamWizard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMail::AntiSpamWizard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail14AntiSpamWizardE_t>.strings))
        return static_cast<void*>(this);
    return KAssistantDialog::qt_metacast(_clname);
}

int KMail::AntiSpamWizard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KAssistantDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN5KMail9ASWizPageE_t {};
} // unnamed namespace

template <> constexpr inline auto KMail::ASWizPage::qt_create_metaobjectdata<qt_meta_tag_ZN5KMail9ASWizPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMail::ASWizPage"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ASWizPage, qt_meta_tag_ZN5KMail9ASWizPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMail::ASWizPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail9ASWizPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail9ASWizPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5KMail9ASWizPageE_t>.metaTypes,
    nullptr
} };

void KMail::ASWizPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ASWizPage *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KMail::ASWizPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMail::ASWizPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail9ASWizPageE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KMail::ASWizPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN5KMail13ASWizInfoPageE_t {};
} // unnamed namespace

template <> constexpr inline auto KMail::ASWizInfoPage::qt_create_metaobjectdata<qt_meta_tag_ZN5KMail13ASWizInfoPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMail::ASWizInfoPage",
        "selectionChanged",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ASWizInfoPage, qt_meta_tag_ZN5KMail13ASWizInfoPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMail::ASWizInfoPage::staticMetaObject = { {
    QMetaObject::SuperData::link<ASWizPage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail13ASWizInfoPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail13ASWizInfoPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5KMail13ASWizInfoPageE_t>.metaTypes,
    nullptr
} };

void KMail::ASWizInfoPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ASWizInfoPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ASWizInfoPage::*)()>(_a, &ASWizInfoPage::selectionChanged, 0))
            return;
    }
}

const QMetaObject *KMail::ASWizInfoPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMail::ASWizInfoPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail13ASWizInfoPageE_t>.strings))
        return static_cast<void*>(this);
    return ASWizPage::qt_metacast(_clname);
}

int KMail::ASWizInfoPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ASWizPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KMail::ASWizInfoPage::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN5KMail18ASWizSpamRulesPageE_t {};
} // unnamed namespace

template <> constexpr inline auto KMail::ASWizSpamRulesPage::qt_create_metaobjectdata<qt_meta_tag_ZN5KMail18ASWizSpamRulesPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMail::ASWizSpamRulesPage",
        "selectionChanged",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ASWizSpamRulesPage, qt_meta_tag_ZN5KMail18ASWizSpamRulesPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMail::ASWizSpamRulesPage::staticMetaObject = { {
    QMetaObject::SuperData::link<ASWizPage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail18ASWizSpamRulesPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail18ASWizSpamRulesPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5KMail18ASWizSpamRulesPageE_t>.metaTypes,
    nullptr
} };

void KMail::ASWizSpamRulesPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ASWizSpamRulesPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ASWizSpamRulesPage::*)()>(_a, &ASWizSpamRulesPage::selectionChanged, 0))
            return;
    }
}

const QMetaObject *KMail::ASWizSpamRulesPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMail::ASWizSpamRulesPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail18ASWizSpamRulesPageE_t>.strings))
        return static_cast<void*>(this);
    return ASWizPage::qt_metacast(_clname);
}

int KMail::ASWizSpamRulesPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ASWizPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KMail::ASWizSpamRulesPage::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN5KMail19ASWizVirusRulesPageE_t {};
} // unnamed namespace

template <> constexpr inline auto KMail::ASWizVirusRulesPage::qt_create_metaobjectdata<qt_meta_tag_ZN5KMail19ASWizVirusRulesPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMail::ASWizVirusRulesPage",
        "selectionChanged",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ASWizVirusRulesPage, qt_meta_tag_ZN5KMail19ASWizVirusRulesPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMail::ASWizVirusRulesPage::staticMetaObject = { {
    QMetaObject::SuperData::link<ASWizPage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail19ASWizVirusRulesPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail19ASWizVirusRulesPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5KMail19ASWizVirusRulesPageE_t>.metaTypes,
    nullptr
} };

void KMail::ASWizVirusRulesPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ASWizVirusRulesPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ASWizVirusRulesPage::*)()>(_a, &ASWizVirusRulesPage::selectionChanged, 0))
            return;
    }
}

const QMetaObject *KMail::ASWizVirusRulesPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMail::ASWizVirusRulesPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail19ASWizVirusRulesPageE_t>.strings))
        return static_cast<void*>(this);
    return ASWizPage::qt_metacast(_clname);
}

int KMail::ASWizVirusRulesPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ASWizPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KMail::ASWizVirusRulesPage::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN5KMail16ASWizSummaryPageE_t {};
} // unnamed namespace

template <> constexpr inline auto KMail::ASWizSummaryPage::qt_create_metaobjectdata<qt_meta_tag_ZN5KMail16ASWizSummaryPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMail::ASWizSummaryPage"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ASWizSummaryPage, qt_meta_tag_ZN5KMail16ASWizSummaryPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMail::ASWizSummaryPage::staticMetaObject = { {
    QMetaObject::SuperData::link<ASWizPage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail16ASWizSummaryPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail16ASWizSummaryPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5KMail16ASWizSummaryPageE_t>.metaTypes,
    nullptr
} };

void KMail::ASWizSummaryPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ASWizSummaryPage *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KMail::ASWizSummaryPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMail::ASWizSummaryPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KMail16ASWizSummaryPageE_t>.strings))
        return static_cast<void*>(this);
    return ASWizPage::qt_metacast(_clname);
}

int KMail::ASWizSummaryPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ASWizPage::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
