// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "markdownplugin_debug.h"


Q_LOGGING_CATEGORY(KMAIL_EDITOR_MARKDOWN_PLUGIN_LOG, "org.kde.pim.kmail_markdownplugin", QtInfoMsg)

