// This file is generated by kconfig_compiler_kf6 from donottracksettings.kcfg.
// All changes you do to this file will be lost.
#ifndef DONOTTRACKSETTINGS_H
#define DONOTTRACKSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class DoNotTrackSettings : public KConfigSkeleton
{
  public:

    static DoNotTrackSettings *self();
    ~DoNotTrackSettings() override;

    /**
      Set donottrack
    */
    static
    void setDoNotTrack( bool v )
    {
      if (!self()->isDoNotTrackImmutable())
        self()->mDoNotTrack = v;
    }

    /**
      Get donottrack
    */
    static
    bool doNotTrack()
    {
      return self()->mDoNotTrack;
    }

    /**
      Is donottrack Immutable
    */
    static
    bool isDoNotTrackImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DoNotTrack" ) );
    }

    /**
      Get Item object corresponding to DoNotTrack()
    */
    ItemBool *doNotTrackItem()
    {
      return mDoNotTrackItem;
    }

  protected:
    DoNotTrackSettings();
    friend class DoNotTrackSettingsHelper;


    // Global
    bool mDoNotTrack;

  private:
    ItemBool *mDoNotTrackItem;
};

#endif

