// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "libdkimverifyconfigure_debug.h"


Q_LOGGING_CATEGORY(LIBDKIMVERIFYCONFIGURE_PLUGIN_LOG, "org.kde.pim.libdkimconfigureplugin", QtInfoMsg)

