// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kaichat_calendarplugin_debug.h"


Q_LOGGING_CATEGORY(KAICHAT_CALENDAR_LOG, "org.kde.kaichat_calendarplugin", QtInfoMsg)

