// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kaichat_addressbookplugin_debug.h"


Q_LOGGING_CATEGORY(KAICHAT_ADDRESSBOOK_LOG, "org.kde.kaichat_addressbookplugin", QtInfoMsg)

