/********************************************************************************
** Form generated from reading UI file 'sendmailsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SENDMAILSETTINGS_H
#define UI_SENDMAILSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SendmailSettings
{
public:
    QFormLayout *formLayout;
    QLabel *label_2;
    KUrlRequester *kcfg_host;
    QLabel *label;
    QLineEdit *kcfg_options;

    void setupUi(QWidget *SendmailSettings)
    {
        if (SendmailSettings->objectName().isEmpty())
            SendmailSettings->setObjectName("SendmailSettings");
        SendmailSettings->resize(400, 159);
        formLayout = new QFormLayout(SendmailSettings);
        formLayout->setObjectName("formLayout");
        formLayout->setHorizontalSpacing(6);
        formLayout->setVerticalSpacing(0);
        formLayout->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(SendmailSettings);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_host = new KUrlRequester(SendmailSettings);
        kcfg_host->setObjectName("kcfg_host");
        kcfg_host->setProperty("kcfg_property", QVariant(QByteArray("text")));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_host);

        label = new QLabel(SendmailSettings);
        label->setObjectName("label");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        kcfg_options = new QLineEdit(SendmailSettings);
        kcfg_options->setObjectName("kcfg_options");
        kcfg_options->setClearButtonEnabled(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_options);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(kcfg_host);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SendmailSettings);

        QMetaObject::connectSlotsByName(SendmailSettings);
    } // setupUi

    void retranslateUi(QWidget *SendmailSettings)
    {
        label_2->setText(tr2i18n("Send&mail Location:", nullptr));
        label->setText(tr2i18n("Sendmail options:", nullptr));
        (void)SendmailSettings;
    } // retranslateUi

};

namespace Ui {
    class SendmailSettings: public Ui_SendmailSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SENDMAILSETTINGS_H

